@@ -108,7 +108,8 @@ void MessageDisplay::redisplayAlarms()
         for (const Event::Ptr& kcalEvent : kcalEvents)
         {
             bool showDefer, showEdit;
-            reinstateFromDisplaying(kcalEvent, event, resource, showEdit, showDefer);
+            if (!reinstateFromDisplaying(kcalEvent, event, resource, showEdit, showDefer))
+                continue;
             const EventId eventId(event);
             if (findEvent(eventId))
                 qCDebug(KALARM_LOG) << "MessageDisplay::redisplayAlarms: Message display already exists:" << eventId;
@@ -209,7 +210,7 @@ MessageDisplay::DeferDlgData* MessageDisplay::createDeferDlg(bool displayClosing
     dlg->setObjectName(QStringLiteral("DeferDlg"));    // used by LikeBack
     dlg->setDeferMinutes(mDefaultDeferMinutes() > 0 ? mDefaultDeferMinutes() : Preferences::defaultDeferTime());
     dlg->setLimit(mEvent());
-    auto* data = new DeferDlgData(dlg);
+    auto data = new DeferDlgData(dlg);
     data->eventId      = mEventId();
     data->alarmType    = mAlarmType();
     data->commandError = mCommandError();
